Name:           sdljava
Version:        0.9.1
Release:        %mkrel 37
Summary:        Java binding to the SDL API
Group:          Development/Java
License:        LGPLv2+
URL:            http://sdljava.sourceforge.net/
# this is http://downloads.sourceforge.net/%%{name}/%%{name}-%%{version}.tar.gz
# with the included Microsoft Copyrighted Arial fonts removed
Source0:        %{name}-%{version}.tar.gz
Source1:        %{name}-runtest.sh
Patch0:         sdljava-0.9.1-regen.patch
Patch1:         sdljava-0.9.1-ftgl213.patch
Patch2:         sdljava-0.9.1-ruby19.patch

BuildRequires:  gcc-c++
BuildRequires:  make
BuildRequires:  pkgconfig(ftgl)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(sdl)
BuildRequires:  pkgconfig(SDL_gfx)
BuildRequires:  pkgconfig(SDL_image)
BuildRequires:  pkgconfig(SDL_mixer)
BuildRequires:  pkgconfig(SDL_ttf)

BuildRequires:  javapackages-local
BuildRequires:  ant
BuildRequires:  swig
BuildRequires:  bsh
BuildRequires:  jdom
BuildRequires:  xml-commons-apis
BuildRequires:  ruby
BuildRequires:  rubygems
# To generate the replacement font symlinks for the sdljava-demo testdata
BuildRequires:  font(dejavusans) fontconfig

Requires:       java
Requires:       javapackages-filesystem
Requires:       bsh
Requires:       jdom

%description
sdljava is a Java binding to the SDL API being developed by Ivan Ganza.

sdljava provides the ability to write games and other applications
from the java programming language. sdljava is designed to be fast,
efficient and easy to use.


%package javadoc
Summary:        Javadoc for %{name}
BuildArch:      noarch

%description javadoc
Javadoc for %{name}.


%package demo
Summary:        Some examples for %{name}
BuildArch:      noarch
Requires:       %{name} = %{version}-%{release}
Requires:       font(dejavusans)
Requires:       javapackages-tools

%description demo
Demonstrations and samples for %{name}.


%prep
%setup -q
%patch0 -p1 -z .regen
%patch1 -p1
%patch2 -p1

find -name '*.jar' -or -name '*.class' -or -name '*.bat' -name '*.so' -delete
rm -r etc/build/gljava/windows etc/build/windows

# Newer ftgl no longer exports the FTFace class
rm src/org/gljava/opengl/ftgl/FTFace.java
iconv -f ISO_8859-2 -t UTF8 docs/CHANGES_0_9_1 > docs/CHANGES_0_9_1.tmp
touch -r docs/CHANGES_0_9_1 docs/CHANGES_0_9_1.tmp
mv docs/CHANGES_0_9_1.tmp docs/CHANGES_0_9_1

# patch in gcc include path so that swig can find it
GCC_PATH=`gcc -print-search-dirs | grep install | cut -f 2 -d " "`
sed -i "s#@GCC_INCLUDE_PATH@#$GCC_PATH/include#g" \
  etc/build/linux/Makefile \
  etc/build/gljava/linux/Makefile \
  etc/build/gljava/linux/ftgl/Makefile

# adjust testdata path in demos
find ./testsrc -name '*.java' | xargs sed -i \
  -e 's|testdata|%{_datadir}/%{name}/testdata|g'

# use system versions of bsh & jdom
build-jar-repository -p lib jdom bsh

# copy the Linux Makefiles into place
cp etc/build/linux/Makefile src/sdljava/native
cp etc/build/gljava/linux/Makefile src/org/gljava/opengl/native
cp etc/build/gljava/linux/ftgl/Makefile src/org/gljava/opengl/native/ftgl

# and remove the swig generated code so that it gets regenerated
rm src/sdljava/native/SDL*_wrap.c src/sdljava/native/SDL_types.h
rm src/org/gljava/opengl/native/glew_wrap.c


%build
# We must add -D__%%{_arch}__ to swigs arguments as swig doesn't do that itself.
# Special case ppc as the define is powerpc not ppc and both ppc and ppc64
# must be set for ppc64, also add -D__LONG_DOUBLE_128__ which works around
# swig barfing on bits/stdlib-ldbl.h
%ifarch ppc
export ARCH_DEFINE="-D__powerpc__ -D__LONG_DOUBLE_128__"
%endif
%ifarch ppc64
export ARCH_DEFINE="-D__powerpc__ -D__powerpc64__ -D__LONG_DOUBLE_128__"
%endif
%ifarch ppc64le
export ARCH_DEFINE="-D__powerpc__ -D__powerpc64__ -D__LITTLE_ENDIAN__ -D\"__BYTE_ORDER__=1234\" -D\"_CALL_ELF=2\" -D__LONG_DOUBLE_128__"
%endif
%ifarch s390x
export ARCH_DEFINE="-D__s390x__ -D__LONG_DOUBLE_128__"
%endif
# special case ix86 as all of ix86 should define __i386__
%ifarch %{ix86}
export ARCH_DEFINE="-D__i386__"
%endif
# arm also needs a bunch of special defines
%ifarch %{arm}
export ARCH_DEFINE="-D__arm__ -D__ARMEL__ -D__ARM_EABI__"
%ifnarch armv5tel armv5tl
export ARCH_DEFINE="$ARCH_DEFINE -D__ARM_PCS_VFP"
%endif
%endif
# All other archs
if [ -z "$ARCH_DEFINE" ]; then
  export ARCH_DEFINE="-D__%{_arch}__"
fi

export JAVA_HOME=%{_jvmdir}/java

pushd src/sdljava/native
make CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing -fPIC"
make libsdljava_gfx.so CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing -fPIC"
popd

pushd src/org/gljava/opengl/native
make CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing -fPIC"
popd

pushd src/org/gljava/opengl/native/ftgl
make CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing -fPIC"
popd

ant jar javadoc


%install
# dirs
mkdir -p $RPM_BUILD_ROOT%{_bindir}
mkdir -p $RPM_BUILD_ROOT%{_libdir}/%{name}
mkdir -p $RPM_BUILD_ROOT%{_datadir}/%{name}
mkdir -p $RPM_BUILD_ROOT%{_jnidir}
mkdir -p $RPM_BUILD_ROOT%{_javadocdir}/%{name}

# jars
install -m 644 lib/%{name}.jar \
  $RPM_BUILD_ROOT%{_jnidir}/%{name}.jar

# native libraries
install -m 755 lib/*.so $RPM_BUILD_ROOT%{_libdir}/%{name}

# javadoc
cp -pr docs/api/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}

# demo scripts
install -m 755 %{SOURCE1} $RPM_BUILD_ROOT%{_bindir}
pushd bin
rm runtest.sh
for i in `ls -1 *.sh`; do
   sed -i -e 's|./runtest.sh|%{_bindir}/%{name}-runtest.sh|g' $i
   FN=`echo $i | awk 'BEGIN { FS="." }{ print $1 }'`
   install -m 755 $i $RPM_BUILD_ROOT%{_bindir}/%{name}-$FN.sh
done
popd

#test data
cp -a testdata $RPM_BUILD_ROOT%{_datadir}/%{name}
rm -f $RPM_BUILD_ROOT%{_datadir}/%{name}/testdata/{arial,arialbd,ariali,arialbi}.ttf
ln -s %_datadir/fonts/TTF/dejavu/DejaVuSans.ttf \
  $RPM_BUILD_ROOT%{_datadir}/%{name}/testdata/arial.ttf
ln -s %_datadir/fonts/dejavu/DejaVuSans-Bold.ttf \
  $RPM_BUILD_ROOT%{_datadir}/%{name}/testdata/arialbd.ttf
ln -s %_datadir/fonts/dejavu/DejaVuSans-Oblique.ttf \
  $RPM_BUILD_ROOT%{_datadir}/%{name}/testdata/ariali.ttf
ln -s %_datadir/fonts/dejavu/DejaVuSans-BoldOblique.ttf \
  $RPM_BUILD_ROOT%{_datadir}/%{name}/testdata/arialbi.ttf


%files
%doc README TODO docs/CHANGES_0_9_1
%{_jnidir}/%{name}.jar
%{_libdir}/%{name}

%files javadoc
%doc %{_javadocdir}/%{name}

%files demo
%{_bindir}/%{name}-*.sh
%{_datadir}/%{name}


%changelog
* Wed Dec 02 2020 luigiwalser <luigiwalser> 0.9.1-37.mga8
+ Revision: 1651371
- rebuild for glew

* Mon Sep 07 2020 daviddavid <daviddavid> 0.9.1-36.mga8
+ Revision: 1623131
- Replace path requires on dejavu with Requires: font(dejavusans)
- Replace unnecessary BuildRequires: jruby with BuildRequires: rubygems
- Drop version prefix from javadocs installation the ghosted symlink
  blocking us from doing this has last shipped in Fedora 16
- Update to match latest java packaging guidelines
- Rebuilt for JDK-11

* Fri Feb 14 2020 umeabot <umeabot> 0.9.1-35.mga8
+ Revision: 1521544
- Mageia 8 Mass Rebuild

* Fri Dec 28 2018 luigiwalser <luigiwalser> 0.9.1-34.mga7
+ Revision: 1345731
- rebuild for SDL_gfx

* Sun Sep 23 2018 umeabot <umeabot> 0.9.1-33.mga7
+ Revision: 1300981
- Mageia 7 Mass Rebuild

* Sun Dec 03 2017 daviddavid <daviddavid> 0.9.1-32.mga7
+ Revision: 1180812
- rebuild for new glew 2.1.0

* Mon Aug 07 2017 daviddavid <daviddavid> 0.9.1-31.mga7
+ Revision: 1138256
- rebuild for new glew 2.0.0

* Mon Jul 18 2016 daviddavid <daviddavid> 0.9.1-30.mga6
+ Revision: 1042440
- resync with fedora24

* Thu Jun 16 2016 daviddavid <daviddavid> 0.9.1-29.mga6
+ Revision: 1021675
- fix armv5tl build

* Thu Jun 16 2016 daviddavid <daviddavid> 0.9.1-28.mga6
+ Revision: 1021671
- sync with fedora 24:
  * fix FTBFS on ARM (rhbz#893157)
  * fix ppc64le build

* Wed Feb 17 2016 umeabot <umeabot> 0.9.1-27.mga6
+ Revision: 962776
- Mageia 6 Mass Rebuild

* Sat Aug 29 2015 daviddavid <daviddavid> 0.9.1-26.mga6
+ Revision: 870904
- rebuild for GLEW 1.13

* Wed Jun 24 2015 akien <akien> 0.9.1-25.mga6
+ Revision: 842157
- Rebuild for GLEW 1.12

* Wed Oct 15 2014 umeabot <umeabot> 0.9.1-24.mga5
+ Revision: 742033
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.9.1-23.mga5
+ Revision: 689095
- Mageia 5 Mass Rebuild

* Mon Sep 01 2014 luigiwalser <luigiwalser> 0.9.1-22.mga5
+ Revision: 670279
- rebuild for glew

* Sat Feb 15 2014 luigiwalser <luigiwalser> 0.9.1-21.mga5
+ Revision: 591739
- rebuild for SDL_gfx

* Sat Oct 19 2013 umeabot <umeabot> 0.9.1-20.mga4
+ Revision: 530462
- Mageia 4 Mass Rebuild

* Wed Jul 24 2013 sander85 <sander85> 0.9.1-19.mga4
+ Revision: 457722
- Rebuild for new glew

* Mon Jan 14 2013 umeabot <umeabot> 0.9.1-18.mga3
+ Revision: 381924
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jan 07 2013 dmorgan <dmorgan> 0.9.1-17.mga3
+ Revision: 340594
- Fix build with ruby1.9 ( Fedora )

* Sun Nov 06 2011 dmorgan <dmorgan> 0.9.1-16.mga2
+ Revision: 164251
- Fix link of fonts
- Sync with fedora
+ gil <gil>
- imported package sdljava


* Thu Jun 23 2011 gil <gil> 0.9.1-0.%%mkrel
- initial rpm